Change Log
----------

..
   All enhancements and patches to edx_ace will be documented
   in this file.  It adheres to the structure of http://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).
   
   This project adheres to Semantic Versioning (http://semver.org/).

.. There should always be an "Unreleased" section for changes pending release.

Unreleased
~~~~~~~~~~

*

[0.1.14] - 2020-03-11
~~~~~~~~~~~~~~~~~~~~~

* Fix trivial warning from deprecated use of attr library.

[0.1.13] - 2019-12-06
~~~~~~~~~~~~~~~~~~~~~

* Django22 Support.

[0.1.12] - 2019-10-16
~~~~~~~~~~~~~~~~~~~~~

* Reply_to field added in emails.

[0.1.10] - 2018-11-01
~~~~~~~~~~~~~~~~~~~~~

* Django lazy text translations are handled properly.


[0.1.9] - 2018-07-13
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* Updated delivery logging


[0.1.0] - 2017-08-08
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Added
_____

* First release on PyPI.
